require([
    'qui/QUI',
    'Ajax'
], function (QUI, QUIAjax) {
    "use strict";

    /**
     * Checks if the cookiebanner has to be loaded.
     * Response contains the control's HTML.
     */
    QUIAjax.get('package_quiqqer_gdpr_ajax_initCookieBannerLoader', function (response) {
        // If we don't get a response all necessary cookies were already accepted
        if (!response) {
            if (window.localStorage) {
                // User already interacted with the banner so set this value for the future.
                window.localStorage.setItem(GDPR.storageKeys.hideBanner, '1');
            }

            return;
        }

        // Create a wrapper to embed the control in
        var CookieConsent = new Element('div', {
            'id'  : 'quiqqer-cookieconsent-wrapper',
            'html': response // response is a string so we set it as the wrapper's html
        });


        // Popup display style needs some extra care to display it in a QUI-popup
        if (CookieConsent.firstChild.dataset.quiOptionsPosition === 'popup') {
            require(['qui/controls/windows/Popup'], function (PopupControl) {
                var Popup = new PopupControl({
                    buttons           : false,
                    backgroundClosable: false,
                    maxHeight         : 305
                });

                Popup.inject(document.body);
                Popup.setContent(CookieConsent.innerHTML);

                var PopupContent = Popup.getContent();

                // Close the popup when "cookie accept" button is clicked
                PopupContent.getElementById('quiqqer-cookieconsent-accept').addEvent('click', function () {
                    Popup.close();
                });

                // Render the CookieConsent-control
                QUI.parse(PopupContent).then(function () {
                    Popup.open().then(function () {
                        Popup.setAttribute('maxHeight', PopupContent.getElementById('quiqqer-cookieconsent-banner').clientHeight + 50);
                        Popup.resize();
                    });
                });
            });

            return;
        }

        // Append the wrapper to the end of the body
        document.body.appendChild(CookieConsent);

        // Parse the control's HTML so data-qui attributes are interpreted & executed
        QUI.parse(CookieConsent);
    }, {
        'package': 'quiqqer/gdpr'
    });
});
