<?php

namespace QUI\GDPR;

use QUI;

/**
 * Class EventHandler
 *
 * @package QUI\GDPR
 */
class EventHandler
{
    /**
     * @param QUI\Template      $Template
     * @param QUI\Projects\Site $Site
     */
    public static function onTemplateSiteFetch($Template, $Site)
    {
        $Project = $Site->getProject();

        $cookiesHash              = '';
        $showBannerOnCookieChange = $Project->getConfig('gdpr.cookieconsent.displayAgainOnCookieChange');

        if ($showBannerOnCookieChange) {
            // Only need to query/calculate the hash if the banner should be displayed when the cookies change
            $cookiesHash = CookieManager::getInstance()->getHashOfAllCookies($Project);
        }

        try {
            $Engine = QUI::getTemplateManager()->getEngine();
        } catch (QUI\Exception $Exception) {
            QUI\System\Log::addDebug($Exception->getMessage());

            return;
        }

        $Engine->assign([
            'cookiesHash'              => $cookiesHash,
            'showBannerOnCookieChange' => $showBannerOnCookieChange
        ]);


        // Loads the cookie banner if LocalStorage isn't available or cookies weren't accepted yet.
        $Template->extendHeader($Engine->fetch(__DIR__ . '/HeaderExtension.tpl'), 0);
    }

    /**
     * Listens to project config save
     *
     * @param string $projectName
     * @param array  $config
     * @param array  $params
     *
     * @throws QUI\Exception
     */
    public static function onProjectConfigSave($projectName, array $config, array $params)
    {
        if (!isset($params['gdpr.cookieconsent.text']) || !isset($params['gdpr.cookieconsent.buttontext'])) {
            return;
        }

        try {
            $Project = QUI::getProject($projectName);
        } catch (QUI\Exception $Exception) {
            return;
        }

        $group = 'quiqqer/gdpr';

        $localeVariables = [
            'setting.text.project.' . $Project->getName()       => json_decode($params['gdpr.cookieconsent.text'], true),
            'setting.buttontext.project.' . $Project->getName() => json_decode(
                $params['gdpr.cookieconsent.buttontext'],
                true
            ),
        ];


        foreach ($localeVariables as $localeVariableName => $localeVariableContent) {
            try {
                QUI\Translator::add($group, $localeVariableName, $group);
            } catch (QUI\Exception $Exception) {
                // Throws error if lang var already exists
            }

            try {
                QUI\Translator::update(
                    $group,
                    $localeVariableName,
                    $group,
                    $localeVariableContent
                );
            } catch (QUI\Exception $Exception) {
                QUI\System\Log::writeException($Exception);

                continue;
            }
        }

        QUI\Translator::publish($group);
    }
}
